/************************************************************************/
/*									*/
/*	plotdemo.c							*/
/*									*/
/*	Copyright (c) 1992, Research Systems Inc.  All rights reserved.	*/
/*									*/
/*	Generate data in IDL, plot it via IDL
/*									*/
/************************************************************************/

#include        <stdio.h>
#include        <ctype.h>
#include        <rpc/rpc.h>
#include	"export.h"
#include	"rpc_idl.h"
#include	<math.h>

main(argc, argv)
     int	argc;
     char	*argv[];
{
    char		*hostname	= NULL;
    CLIENT		* client;
    varinfo_t		s;
    varinfo_t		ds;
    LONG		s_dim[1];
    LONG		ds_dim[1];
    float		s_data[100];
    float		ds_data[100];
    int			i;
    double		x;


    /*	Set up connection with IDL server. If there is a command	*/
    /*	line argument, assume that it is the hostname where the IDL	*/
    /*	server is running.						*/

    if(argc == 2)
	hostname	= argv[1];
    
    client	= register_idl_client( 0, hostname, NULL );

    if( client == NULL )
	printf("Can't find server.\n"), exit(1);

    /*	Build a sine wave and a damped sine wave.			*/

    bzero( &s, sizeof(s) );
    bzero( &ds, sizeof(ds) );
    s_dim[0]	= 100;		/*	vector of 100 elements		*/
    ds_dim[0]	= 100;		/*	vector of 100 elements		*/
    
    /*	S=sin(6*!pi/100. * findgen(100) )				*/
    /*	ds=s*exp(-findgen(100)/20.)					*/

    x= 6.0 * M_PI / 100.0;
    
    printf("Generating data\n");
    
    for( i = 0; i < 100; ++i ) {
	s_data[i]	= sin( x * (double)i );
	ds_data[i]	= s_data[i] * exp( -((double)i)/20.0 );
    }

    if( !v_fill_array( &s, "SINE_WAVE", TYP_FLOAT, 1, s_dim,
		      (UCHAR*)s_data, sizeof(s_data)) )
	printf( "v_fill_array SINE_WAVE failed to allocate memory\n"), exit(1);
    
    if( !v_fill_array(&ds, "DAMPED_SINE", TYP_FLOAT, 1, ds_dim,
		      (UCHAR*)ds_data, sizeof(ds_data) ) ) {
	printf( "v_fill_array DAMPED_SINE failed to allocate memory\n");
	exit(1);
    }

    printf("sending variables to server\n");
    if(set_idl_variable( client, &s ) != 1 ||
       set_idl_variable( client, &ds ) != 1 ) {
	printf("unable to set variables\n");
	exit(1);
    }
    
    /*	Send commands to server. 					*/


    /*	Plot the two waves						*/

    printf("plotting\n");
    if(send_idl_command( client, "plot,sine_wave" ) != 1 ||
       send_idl_command( client, "oplot,damped_sine" ) != 1 ) {
	printf("Problems plotting\n");
	exit(1);
    }

    /*	Plot the cross product of the two waves				*/

    printf("Showing surface\n");
    if(send_idl_command( client, "window,1") != 1 ||
       send_idl_command( client, "x = damped_sine # sine_wave" ) != 1 ||
       send_idl_command( client, "surface,x & tv,bytscl(x)" ) != 1 ) {
	printf("Problems generating surface\n");
    }
    
    /*	Disconnect from server						*/
    unregister_idl_client( client );
}
